#!/bin/sh
#
# Copyright (c) 2022  StorPool <support@storpool.com>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.

set -e

systemd_booting()
{
	if [ "$CGCONFIG_FORCE_STARTUP" = '1' ]; then
		echo 'Forced cgconfig startup requested'
		return 0
	fi

	local res=0
	local output=''
	output="$(systemctl is-system-running)" || res="$?"
	echo "systemctl is-system-running exited with code $res, output: $output"
	case "$output" in
		initializing|starting)
			echo 'We seem to be in the boot sequence'
			return 0
			;;

		*)
			echo 'We do not seem to be in the boot sequence' 1>&2
			return 1
			;;
	esac
}

start_cgconfig()
{
	if ! systemd_booting; then
		echo "This tool should only be invoked during the system boot process" 1>&2
		exit 1
	fi

	echo 'Running cgconfigparser'
	/usr/sbin/cgconfigparser -l /etc/cgconfig.conf -L /etc/cgconfig.d -s 1664
}

stop_cgconfig()
{
	echo "The cgconfig service does not support the $1 action"
}

case "$1" in
	reload|stop)
		stop_cgconfig "$1"
		;;

	start)
		start_cgconfig
		;;

	*)
		echo "Unrecognized action '$1', only start supported" 1>&2
		exit 1
		;;
esac
